==> ask-cli-1.5.0.tgz: package/lib/dialog/file-writer.js <==
'use strict';

const parser = require('./response-parser');
const CONSTANTS = require('../utils/constants');
const jsonUtility = require('../utils/json-utility');

module.exports = {
    writeUserSays: writeUserSays,
    writeResponses: writeResponses,
    writeError: writeError
};

function writeUserSays(outputWriteStream, text) {
    if (outputWriteStream) {
        const content = CONSTANTS.SIMULATE_CONTENT_PREFIX.USER + text;
        writeToOutputFile(
            outputWriteStream,
            CONSTANTS.SIMULATE_FILE_LINE.USER_SAYS_START_LINE,
            content,
            CONSTANTS.SIMULATE_FILE_LINE.USER_SAYS_END_LINE
        );
    }
}

function writeError(response, outputWriteStream) {
    if (outputWriteStream) {
        const content = CONSTANTS.SIMULATE_CONTENT_PREFIX.SYSTEM_ERROR + JSON.stringify(response, null, 2);
        writeToOutputFile(
            outputWriteStream,
            CONSTANTS.SIMULATE_FILE_LINE.SYSTEM_ERROR_START_LINE,
            content,
            CONSTANTS.SIMULATE_FILE_LINE.SYSTEM_ERROR_END_LINE
        );
    }
}

function writeResponses(response, outputWriteStream) {
    const captions = jsonUtility.getPropertyValueFromObject(
        response, ['result', 'alexaExecutionInfo', 'alexaResponses']
    );

    if (outputWriteStream) {
        writeResponse(response, captions, outputWriteStream);
    } 
}

function writeResponse(response, captions, outputWriteStream) {
    const jsonInputForRecord = JSON.stringify(parser.getJsonInput(response), null, 2);
    const jsonOutputForRecord = JSON.stringify(parser.getJsonOutput(response), null, 2);
    writeJsonInput(outputWriteStream, jsonInputForRecord);
    writeCaptions(captions, outputWriteStream);
    writeJsonOutput(outputWriteStream, jsonOutputForRecord);
}

function writeToOutputFile(outputWriteStream, start, content, end) {
    const contentToWrite = `${start}\r\n${content}\r\n${end}\r\n\r\n`;
    outputWriteStream.write(contentToWrite);
}

function writeJsonInput(outputWriteStream, jsonInput) {
    const content = CONSTANTS.SIMULATE_CONTENT_PREFIX.JSON_INPUT + jsonInput;
    writeToOutputFile(
        outputWriteStream,
        CONSTANTS.SIMULATE_FILE_LINE.JSON_INPUT_START_LINE,
        content,
        CONSTANTS.SIMULATE_FILE_LINE.JSON_INPUT_END_LINE
    );
}

function writeJsonOutput(outputWriteStream, jsonOutput) {
    const content = CONSTANTS.SIMULATE_CONTENT_PREFIX.JSON_OUTPUT + jsonOutput;
    writeToOutputFile(
        outputWriteStream,
        CONSTANTS.SIMULATE_FILE_LINE.JSON_OUTPUT_START_LINE,
        content,
        CONSTANTS.SIMULATE_FILE_LINE.JSON_OUTPUT_END_LINE
    );
}

function writeCaption(outputWriteStream, caption) {
    const content = CONSTANTS.SIMULATE_CONTENT_PREFIX.ALEXA + caption;
    writeToOutputFile(
        outputWriteStream,
        CONSTANTS.SIMULATE_FILE_LINE.ALEXA_RESPONDS_START_LINE,
        content,
        CONSTANTS.SIMULATE_FILE_LINE.ALEXA_RESPONDS_END_LINE
    );
}

function writeCaptions(captions, outputWriteStream) {
    if (captions && captions.length > 0) {
        captions.forEach(item => {
            writeCaption(outputWriteStream, item.content.caption);
        });
    } else {
        writeCaption(outputWriteStream, '');
    }
}

==> ask-cli-1.6.0.tgz: package/lib/dialog/file-writer.js <==
'use strict';

const parser = require('./response-parser');
const CONSTANTS = require('../utils/constants');
const jsonUtility = require('../utils/json-utility');

module.exports = {
    writeUserSays: writeUserSays,
    writeResponses: writeResponses,
    writeError: writeError
};

function writeUserSays(outputWriteStream, text) {
    if (outputWriteStream) {
        const content = CONSTANTS.SIMULATE_CONTENT_PREFIX.USER + text;
        writeToOutputFile(
            outputWriteStream,
            CONSTANTS.SIMULATE_FILE_LINE.USER_SAYS_START_LINE,
            content,
            CONSTANTS.SIMULATE_FILE_LINE.USER_SAYS_END_LINE
        );
    }
}

function writeError(response, outputWriteStream) {
    if (outputWriteStream) {
        const content = CONSTANTS.SIMULATE_CONTENT_PREFIX.SYSTEM_ERROR + JSON.stringify(response, null, 2);
        writeToOutputFile(
            outputWriteStream,
            CONSTANTS.SIMULATE_FILE_LINE.SYSTEM_ERROR_START_LINE,
            content,
            CONSTANTS.SIMULATE_FILE_LINE.SYSTEM_ERROR_END_LINE
        );
    }
}

function writeResponses(response, outputWriteStream) {
    const captions = jsonUtility.getPropertyValueFromObject(
        response, ['result', 'alexaExecutionInfo', 'alexaResponses']
    );

    if (outputWriteStream) {
        writeResponse(response, captions, outputWriteStream);
    } 
}

function writeResponse(response, captions, outputWriteStream) {
    const jsonInputAndOutputs = parser.getJsonInputAndOutputs(response);
    const consideredIntent = JSON.stringify(parser.getConsideredIntents(response), null, 2);
    writeConsideredIntents(outputWriteStream, consideredIntent);
    writeJsonInputAndOutput(outputWriteStream, jsonInputAndOutputs);
    writeCaptions(captions, outputWriteStream);
}

function writeToOutputFile(outputWriteStream, start, content, end) {
    const contentToWrite = `${start}\r\n${content}\r\n${end}\r\n\r\n`;
    outputWriteStream.write(contentToWrite);
}

function writeJsonInputAndOutput(outputWriteStream, jsonInputAndOutputs) {
    jsonInputAndOutputs.forEach(jsonInputAndOutput => {
        writeJsonInput(outputWriteStream, JSON.stringify(jsonInputAndOutput.jsonInput, null, 2));
        writeJsonOutput(outputWriteStream, JSON.stringify(jsonInputAndOutput.jsonOutput, null, 2));
    });
}

function writeJsonInput(outputWriteStream, jsonInput) {
    const content = CONSTANTS.SIMULATE_CONTENT_PREFIX.JSON_INPUT + jsonInput;
    writeToOutputFile(
        outputWriteStream,
        CONSTANTS.SIMULATE_FILE_LINE.JSON_INPUT_START_LINE,
        content,
        CONSTANTS.SIMULATE_FILE_LINE.JSON_INPUT_END_LINE
    );
}

function writeJsonOutput(outputWriteStream, jsonOutput) {
    const content = CONSTANTS.SIMULATE_CONTENT_PREFIX.JSON_OUTPUT + jsonOutput;
    writeToOutputFile(
        outputWriteStream,
        CONSTANTS.SIMULATE_FILE_LINE.JSON_OUTPUT_START_LINE,
        content,
        CONSTANTS.SIMULATE_FILE_LINE.JSON_OUTPUT_END_LINE
    );
}

function writeConsideredIntents(outputWriteStream, consideredIntents) {
    const content = CONSTANTS.SIMULATE_CONTENT_PREFIX.CONSIDERED_INTENT + consideredIntents;
    writeToOutputFile(
        outputWriteStream,
        CONSTANTS.SIMULATE_FILE_LINE.CONSIDERED_INTENT_START_LINE,
        content,
        CONSTANTS.SIMULATE_FILE_LINE.CONSIDERED_INTENT_END_LINE
    );
}

function writeCaption(outputWriteStream, caption) {
    const content = CONSTANTS.SIMULATE_CONTENT_PREFIX.ALEXA + caption;
    writeToOutputFile(
        outputWriteStream,
        CONSTANTS.SIMULATE_FILE_LINE.ALEXA_RESPONDS_START_LINE,
        content,
        CONSTANTS.SIMULATE_FILE_LINE.ALEXA_RESPONDS_END_LINE
    );
}

function writeCaptions(captions, outputWriteStream) {
    if (captions && captions.length > 0) {
        captions.forEach(item => {
            writeCaption(outputWriteStream, item.content.caption);
        });
    } else {
        writeCaption(outputWriteStream, '');
    }
}
